@@ -20,8 +20,9 @@ def check_latest_version():
 
     page = pypi.get_project_page(package_name)
     latest_version = page.packages[0].version
+    package_url = page.packages[0].url
     print('latest_version is: ' + latest_version)
-
+    print ('package_url is: ' + package_url)
     if current_version == latest_version:
         logger.log(message="Latest version detected, proceeding.", log_level="info", to_file=True, to_terminal=False)
     else:
